@@ -730,6 +730,12 @@ soup_ntlm_parse_challenge (const char *challenge,
 	*ntlmv2_session = (flags & NTLM_FLAGS_NEGOTIATE_NTLMV2) ? TRUE : FALSE;
 	/* To know if NTLMv2 responses should be calculated */
 	*negotiate_target = (flags & NTLM_FLAGS_NEGOTIATE_TARGET_INFORMATION ) ? TRUE : FALSE;
+        if (*negotiate_target) {
+            if (clen < NTLM_CHALLENGE_TARGET_INFORMATION_OFFSET + sizeof (target)) {
+                g_free (chall);
+                return FALSE;
+            }
+        }
 
 	if (default_domain) {
 		memcpy (&domain, chall + NTLM_CHALLENGE_DOMAIN_STRING_OFFSET, sizeof (domain));
@@ -812,7 +818,18 @@ calc_hmac_md5 (unsigned char *hmac, const guchar *key, gsize key_sz, const gucha
 	hex_pos = hmac_hex;
 	for (count = 0; count < HMAC_MD5_LENGTH; count++)
 	{
+		/* The 'hh' sscanf format modifier is C99, so we enable it on
+		 * non-Windows or if __USE_MINGW_ANSI_STDIO is enabled or`
+		 * if we are building on Visual Studio 2015 or later
+		 */
+#if !defined (G_OS_WIN32) || (__USE_MINGW_ANSI_STDIO == 1) || (_MSC_VER >= 1900)
 		sscanf(hex_pos, "%2hhx", &hmac[count]);
+#else
+		unsigned int tmp_hmac;
+		sscanf(hex_pos, "%2x", &tmp_hmac);
+		hmac[count] = (guint8)tmp_hmac;
+#endif
+
 		hex_pos += 2;
 	}
 	g_free(hmac_hex);
