@@ -3,8 +3,8 @@
  * Copyright (C) 2008 Red Hat, Inc.
  */
 
-#ifndef SOUP_COOKIE_JAR_H
-#define SOUP_COOKIE_JAR_H 1
+#ifndef __SOUP_COOKIE_JAR_H__
+#define __SOUP_COOKIE_JAR_H__ 1
 
 #include <libsoup/soup-types.h>
 
@@ -88,10 +88,12 @@ SoupCookieJarAcceptPolicy soup_cookie_jar_get_accept_policy           (SoupCooki
 SOUP_AVAILABLE_IN_2_40
 gboolean                  soup_cookie_jar_is_persistent               (SoupCookieJar             *jar);
 
+#ifndef SOUP_DISABLE_DEPRECATED
 SOUP_AVAILABLE_IN_2_24
 SOUP_DEPRECATED_IN_2_26
 void                      soup_cookie_jar_save                        (SoupCookieJar             *jar);
+#endif
 
 G_END_DECLS
 
-#endif /* SOUP_COOKIE_JAR_H */
+#endif /* __SOUP_COOKIE_JAR_H__ */
